@@ -1,11 +1,11 @@
 package Alien::libbrotli;
 use 5.012;
 
-our $VERSION = "1.0.7.2";
+our $VERSION = "1.0.7.3";
 
 use XS::Loader;
 
-XS::Loader::bootstrap();
+XS::Loader::load_noboot();
 
 =head1 NAME
 
